HypothesisBoard

Struct HypothesisBoard 

pub struct HypothesisBoard { /* private fields */ }
Main API for hypothesis management

Implementations

Source

impl HypothesisBoard

pub fn new(storage: Arc<dyn HypothesisStorage>) -> Self

pub fn in_memory() -> Self

pub async fn propose( &self, statement: impl Into<String>, prior: Confidence, ) -> Result<HypothesisId>

Propose a new hypothesis with explicit prior

pub async fn propose_with_max_uncertainty( &self, statement: impl Into<String>, ) -> Result<HypothesisId>

Propose with maximum uncertainty (0.5) convenience method

pub async fn update_with_evidence( &self, id: HypothesisId, likelihood_h: f64, likelihood_not_h: f64, ) -> Result<Confidence>

Update hypothesis confidence using Bayes formula

pub async fn set_status( &self, id: HypothesisId, status: HypothesisStatus, ) -> Result<()>

Update hypothesis status

pub async fn get(&self, id: HypothesisId) -> Result<Option<Hypothesis>>

Get a hypothesis by ID

pub async fn list(&self) -> Result<Vec<Hypothesis>>

List all hypotheses

pub async fn delete(&self, id: HypothesisId) -> Result<bool>

Delete a hypothesis

pub async fn attach_evidence( &self, hypothesis_id: HypothesisId, evidence_type: EvidenceType, strength: f64, metadata: EvidenceMetadata, ) -> Result<(EvidenceId, Confidence)>

Attach evidence to a hypothesis and update confidence

This is the primary method for evidence attachment. It:

  1. Stores the evidence
  2. Converts strength to likelihood ratio
  3. Updates hypothesis confidence using Bayes formula
pub async fn get_evidence(&self, id: EvidenceId) -> Result<Option<Evidence>>

Get evidence by ID

pub async fn list_evidence( &self, hypothesis_id: HypothesisId, ) -> Result<Vec<Evidence>>

List all evidence for a hypothesis

pub async fn list_supporting_evidence( &self, hypothesis_id: HypothesisId, ) -> Result<Vec<Evidence>>

Trace supporting evidence for a hypothesis

pub async fn list_refuting_evidence( &self, hypothesis_id: HypothesisId, ) -> Result<Vec<Evidence>>

Trace refuting evidence for a hypothesis

pub async fn delete_evidence(&self, id: EvidenceId) -> Result<bool>

Delete evidence

pub async fn state_at( &self, checkpoint_service: &CheckpointService, checkpoint_id: CheckpointId, ) -> Result<Option<HypothesisState>>

Query hypothesis state at a past checkpoint time

This enables time-travel queries: “What did I believe at checkpoint X?”

pub async fn update_confidence_direct( &self, id: HypothesisId, confidence: Confidence, ) -> Result<()>

Directly sets confidence without evidence (used by propagation system)

This method bypasses the normal evidence-based update path and is intended for use by the confidence propagation system, which updates dependents based on cascade computations.